part of 'role_bloc.dart';

abstract class RoleState extends Equatable {
  const RoleState();

  @override
  List<Object> get props => [];
}

class RoleInitial extends RoleState {}

class RoleLoadedState extends RoleState {
  final List<RBAC> roles;
  const RoleLoadedState({required this.roles});
}

class RoleLoadingState extends RoleState {}

class RoleErrorState extends RoleState {
  final String message;
  const RoleErrorState({required this.message});
}

class RoleAddedState extends RoleState {
  final Map<dynamic, dynamic> response;
  const RoleAddedState({required this.response});
}
class RoleUpdatedState extends RoleState {
  final Map<dynamic, dynamic> response;
  const RoleUpdatedState({required this.response});
}
class RoleDeletedState extends RoleState{
  final bool success;
  const RoleDeletedState({required this.success});
}


